@@ -18,7 +18,12 @@
     02110-1301, USA.
 */
 
+#ifndef TEST_MODEL_HELPERS_H
+#define TEST_MODEL_HELPERS_H
+
 #include <QString>
+#include <QStandardItem>
+#include <QSignalSpy>
 
 namespace TestModelHelpers
 {
@@ -65,7 +70,7 @@ inline QString rowSpyToText(const QSignalSpy &spy)
     }
     QString str;
     for (int i = 0; i < spy.count(); ++i) {
-        str += spy.at(i).at(1).toString() + ',' + spy.at(i).at(2).toString();
+        str += spy.at(i).at(1).toString() + QLatin1Char(',') + spy.at(i).at(2).toString();
         if (i + 1 < spy.count()) {
             str += QLatin1Char(';');
         }
@@ -74,4 +79,4 @@ inline QString rowSpyToText(const QSignalSpy &spy)
 }
 
 }
-
+#endif
