@@ -19,18 +19,18 @@
     02110-1301, USA.
 */
 
-#ifndef KBREADCRUMBSPROXYMODEL_H
-#define KBREADCRUMBSPROXYMODEL_H
+#ifndef KBREADCRUMBSELECTIONMODEL_H
+#define KBREADCRUMBSELECTIONMODEL_H
 
-#include <QtCore/QItemSelectionModel>
-#include <QtCore/QAbstractItemModel>
+#include <QItemSelectionModel>
+#include <QAbstractItemModel>
 
 #include "kitemmodels_export.h"
 
 class KBreadcrumbSelectionModelPrivate;
 
 /**
-  @class KBreadcrumbSelectionModel kbreadcrumbselectionmodel.h
+  @class KBreadcrumbSelectionModel kbreadcrumbselectionmodel.h KBreadcrumbSelectionModel
 
   @brief Selects the parents of selected items to create breadcrumbs
 
@@ -115,9 +115,9 @@ public:
         MakeBreadcrumbSelectionInSelf
     };
 
-    explicit KBreadcrumbSelectionModel(QItemSelectionModel *selectionModel, QObject *parent = 0);
-    KBreadcrumbSelectionModel(QItemSelectionModel *selectionModel, BreadcrumbTarget target, QObject *parent = 0);
-    virtual ~KBreadcrumbSelectionModel();
+    explicit KBreadcrumbSelectionModel(QItemSelectionModel *selectionModel, QObject *parent = nullptr);
+    KBreadcrumbSelectionModel(QItemSelectionModel *selectionModel, BreadcrumbTarget target, QObject *parent = nullptr);
+    ~KBreadcrumbSelectionModel() override;
 
     /**
       Returns whether the actual selection in included in the proxy.
@@ -144,9 +144,9 @@ public:
     */
     void setBreadcrumbLength(int breadcrumbLength);
 
-    /* reimp */ void select(const QModelIndex &index, QItemSelectionModel::SelectionFlags command);
+    void select(const QModelIndex &index, QItemSelectionModel::SelectionFlags command) override;
 
-    /* reimp */ void select(const QItemSelection &selection, QItemSelectionModel::SelectionFlags command);
+    void select(const QItemSelection &selection, QItemSelectionModel::SelectionFlags command) override;
 
 protected:
     KBreadcrumbSelectionModelPrivate *const d_ptr;
