@@ -22,9 +22,9 @@
 
 #include "kdescendantsproxymodel.h"
 
-#include <QtCore/QStringList>
-#include <QtCore/QTimer>
-#include <QtCore/QDebug>
+#include <QStringList>
+#include <QTimer>
+#include <QDebug>
 
 #include "kbihash_p.h"
 
@@ -901,6 +901,8 @@ void KDescendantsProxyModelPrivate::sourceLayoutAboutToBeChanged()
         return;
     }
 
+    emit q->layoutAboutToBeChanged();
+
     QPersistentModelIndex srcPersistentIndex;
     Q_FOREACH (const QPersistentModelIndex &proxyPersistentIndex, q->persistentIndexList()) {
         m_proxyIndexes << proxyPersistentIndex;
@@ -909,8 +911,6 @@ void KDescendantsProxyModelPrivate::sourceLayoutAboutToBeChanged()
         Q_ASSERT(srcPersistentIndex.isValid());
         m_layoutChangePersistentIndexes << srcPersistentIndex;
     }
-
-    q->layoutAboutToBeChanged();
 }
 
 void KDescendantsProxyModelPrivate::sourceLayoutChanged()
@@ -937,7 +937,7 @@ void KDescendantsProxyModelPrivate::sourceLayoutChanged()
     m_layoutChangePersistentIndexes.clear();
     m_proxyIndexes.clear();
 
-    q->layoutChanged();
+    emit q->layoutChanged();
 }
 
 void KDescendantsProxyModelPrivate::sourceDataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight)
