@@ -21,9 +21,9 @@
 
 #include "kselectionproxymodel.h"
 
-#include <QtCore/QStack>
-#include <QtCore/QStringList>
-#include <QtCore/QPointer>
+#include <QStack>
+#include <QStringList>
+#include <QPointer>
 #include <QItemSelectionRange>
 
 #include "kmodelindexproxymapper.h"
@@ -399,7 +399,7 @@ static QItemSelection kNormalizeSelection(QItemSelection selection)
     }
 
     RangeLessThan lt;
-    qSort(selection.begin(), selection.end(), lt);
+    std::sort(selection.begin(), selection.end(), lt);
     return stableNormalizeSelection(selection);
 }
 
@@ -408,7 +408,7 @@ class KSelectionProxyModelPrivate
 public:
     KSelectionProxyModelPrivate(KSelectionProxyModel *model)
         : q_ptr(model),
-          m_indexMapper(0),
+          m_indexMapper(nullptr),
           m_startWithChildTrees(false),
           m_omitChildren(false),
           m_omitDescendants(false),
@@ -423,7 +423,7 @@ public:
           m_layoutChanging(false),
           m_ignoreNextLayoutAboutToBeChanged(false),
           m_ignoreNextLayoutChanged(false),
-          m_selectionModel(0),
+          m_selectionModel(nullptr),
           m_filterBehavior(KSelectionProxyModel::InvalidBehavior)
     {
     }
@@ -1110,7 +1110,7 @@ bool KSelectionProxyModelPrivate::rootWillBeRemoved(const QItemSelection &select
 {
     Q_ASSERT(root.isValid());
 
-    for (auto r : selection) {
+    for (auto& r : selection) {
         if (m_includeAllSelected) {
             if (r.parent() == root.parent() && root.row() <= r.bottom() && root.row() >= r.top()) {
                 return true;
@@ -1667,7 +1667,7 @@ void KSelectionProxyModelPrivate::removeParentMappings(const QModelIndex &parent
             if (proxyGrandParent == parent) {
                 if (!flatList)
                     // Due to recursive calls, we could have several iterators on the container
-                    // when erase is called. That's safe accoring to the QHash::iterator docs though.
+                    // when erase is called. That's safe according to the QHash::iterator docs though.
                 {
                     removeParentMappings(it.key(), 0, q->sourceModel()->rowCount(it.value()) - 1);
                 }
@@ -2013,7 +2013,7 @@ KSelectionProxyModel::KSelectionProxyModel(QItemSelectionModel *selectionModel,
 }
 
 KSelectionProxyModel::KSelectionProxyModel()
-    : QAbstractProxyModel(0), d_ptr(new KSelectionProxyModelPrivate(this))
+    : QAbstractProxyModel(nullptr), d_ptr(new KSelectionProxyModelPrivate(this))
 {
 }
 
@@ -2169,7 +2169,7 @@ QModelIndex KSelectionProxyModel::mapToSource(const QModelIndex &proxyIndex) con
 
     Q_ASSERT(proxyIndex.model() == this);
 
-    if (proxyIndex.internalPointer() == 0) {
+    if (proxyIndex.internalPointer() == nullptr) {
         return d->mapTopLevelToSource(proxyIndex.row(), proxyIndex.column());
     }
 
